==> PPDF_1_0.zip: PubMedPDF/author.php <==
<?php
	include "header.php";
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";

	### HOME > Initial ###
	if($initial = @$_GET["initial"]){

		# navibar
		$name = "Author [".$initial."]";
		$pass = "author.php~~initial=".$initial;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > ".$initial;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";

		$sql = "SELECT * FROM ".$T_AUTHOR." WHERE Author like '".$initial."%' ORDER BY Author";
		$res = mysql_query($sql, $conn);
		$i=0;
		$td=0;
		echo "<table><tr>";
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			# get author's items
			$sql2 = "SELECT * FROM ".$T_ID." WHERE Author like '%[".$row["id"]."]%' ORDER BY Year DESC";
			$res2 = mysql_query($sql2, $conn);
			while($row2 = mysql_fetch_array($res2, MYSQL_ASSOC)){
				$tmp = $row2["Author"].$row2["Title"];
				if(!in_array($tmp, $tmp2)){
					$tmp2[] = $tmp;
					$item[$i] = $row2["PMID"];
					$i++;
				}
			}
			if(!($td % 4)) echo "</tr><tr>";
			echo "<td>";
			echo "<a href=\"author.php?author=".$row["id"]."\">".$row["Author"]."</a> (".mysql_num_rows($res2).") &nbsp;";
			echo "</td>";
			$td ++;
		}
		echo "</tr></table>";
		
		echo "<hr>";
		PAPER_DESCRIPTION($item,$user);

	### HOME > Initial > Author ###
	}elseif(($id = @$_GET["author"]) && !@$_GET["year"] ){
	
		$sql = "select * from ".$T_AUTHOR." where id='".$id."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$author = $row["Author"];
		$initial = substr($author,0,1);

		# navibar
		$name = $author;
		$pass = "author.php~~author=".$id;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > <a href=\"author.php?initial=".$initial."\">".$initial."</a> > ".$author;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";

		# get author's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Author like '%[".$id."]%' ORDER BY Year DESC";
		$res = mysql_query($sql, $conn);
		
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$year[$row["Year"]] ++;
			$item[$i] = $row["PMID"];
		}

		# year bar
		foreach($year as $key => $value){
			echo "<a href=\"author.php?author=".$id."&year=".$key."\">".$key."</a> (".$value.") &nbsp;";
		}
		echo "<hr>";
		PAPER_DESCRIPTION($item,$user);

	### HOME > Initial > Author > Year ###
	}elseif($year = @$_GET["year"]){

		$id = @$_GET["author"];
		$sql = "select * from ".$T_AUTHOR." where id='".$id."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$author = $row["Author"];
		$initial = substr($author,0,1);

		# navibar
		$name = $author."_".$year;
		$pass = "author.php~~author=".$id."^^year=".$year;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > <a href=\"author.php?initial=".$initial."\">".$initial."</a> > <a href=\"author.php?author=".$id."\">".$author."</a> > ".$year;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";


		# get author's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Author like '%[".$id."]%' AND Year='".$year."' ORDER BY PMID DESC";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$item[$i] = $row["PMID"];
		}
		PAPER_DESCRIPTION($item,$user);
	}


	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3.zip: PubMedPDF/author.php <==
<?php
	include "header.php";
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";

	### HOME > Initial ###
	if($initial = @$_GET["initial"]){

		# navibar
		$name = "Author [".$initial."]";
		$pass = "author.php~~initial=".$initial;
		$shortcut = "[<a href=\"javascript:disp('include/reg_shortcut.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > ".$initial;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";

		$sql = "SELECT * FROM ".$T_AUTHOR." WHERE Author like '".$initial."%' ORDER BY Author";
		$res = mysql_query($sql, $conn);
		$i=0;
		$td=0;
		echo "<table><tr>";
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			# get author's items
			$sql2 = "SELECT * FROM ".$T_ID." WHERE Author like '%[".$row["id"]."]%' ORDER BY Year DESC";
			$res2 = mysql_query($sql2, $conn);
			while($row2 = mysql_fetch_array($res2, MYSQL_ASSOC)){
				$tmp = $row2["Author"].$row2["Title"];
				if(!in_array($tmp, $tmp2)){
					$tmp2[] = $tmp;
					$item[$i] = $row2["PMID"];
					$i++;
				}
			}
			if(!($td % 4)) echo "</tr><tr>";
			echo "<td>";
			echo "<a href=\"author.php?author=".$row["id"]."\">".$row["Author"]."</a> (".mysql_num_rows($res2).") &nbsp;";
			echo "</td>";
			$td ++;
		}
		echo "</tr></table>";
		
		echo "<hr>";
		PAPER_DESCRIPTION($item,$user,$perm);

	### HOME > Initial > Author ###
	}elseif(($id = @$_GET["author"]) && !@$_GET["year"] ){
	
		$sql = "select * from ".$T_AUTHOR." where id='".$id."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$author = $row["Author"];
		$initial = substr($author,0,1);

		# navibar
		$name = $author;
		$pass = "author.php~~author=".$id;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > <a href=\"author.php?initial=".$initial."\">".$initial."</a> > ".$author;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";

		# get author's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Author like '%[".$id."]%' ORDER BY Year DESC";
		$res = mysql_query($sql, $conn);
		
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$year[$row["Year"]] ++;
			$item[$i] = $row["PMID"];
		}

		# year bar
		foreach($year as $key => $value){
			echo "<a href=\"author.php?author=".$id."&year=".$key."\">".$key."</a> (".$value.") &nbsp;";
		}
		echo "<hr>";
		PAPER_DESCRIPTION($item,$user,$perm);

	### HOME > Initial > Author > Year ###
	}elseif($year = @$_GET["year"]){

		$id = @$_GET["author"];
		$sql = "select * from ".$T_AUTHOR." where id='".$id."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$author = $row["Author"];
		$initial = substr($author,0,1);

		# navibar
		$name = $author."_".$year;
		$pass = "author.php~~author=".$id."^^year=".$year;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > <a href=\"author.php?initial=".$initial."\">".$initial."</a> > <a href=\"author.php?author=".$id."\">".$author."</a> > ".$year;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";


		# get author's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Author like '%[".$id."]%' AND Year='".$year."' ORDER BY PMID DESC";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$item[$i] = $row["PMID"];
		}
		PAPER_DESCRIPTION($item,$user,$perm);
	}


	include (XOOPS_ROOT_PATH."/footer.php");
?>
